# `BioClients.uniprot`

## UniProt

Access to Uniprot REST API.

UniprotKB = Uniprot Knowledge Base

* <https://www.uniprot.org>
* <https://www.uniprot.org/help/api>
* <https://www.uniprot.org/uniprot>

```
python3 -m BioClients.uniprot.Client --uids Q14790 getData
```
